--- title: "wallaroo.inference_result" type: docs linkTitle: "wallaroo.inference_result" ---
class InferenceResult:
InferenceResult(gql_client: Optional[gql.client.Client], data: Dict[str, Any])

Initializes an InferenceResult.

###### Parameters

- gql.Client gql_client: GQL client that this can pass to created objects.
- Dict[str, Any] data: Response parsed from JSON inference result body.

def data(self) -> List[numpy.ndarray]:

Returns the inference result data.

def model(self) -> Tuple[str, str]:

Returns the model this inference was generated by.

def time_elapsed(self) -> datetime.timedelta:

Returns the total time taken by the engine.

def timestamp(self) -> datetime.datetime:

Returns the time at which this inference occurred.

def input_data(self) -> Dict[str, Any]:

Returns the input data for this inference result.

def shadow_data(self) -> Optional[Dict[str, numpy.ndarray]]: